<TS language="eo" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Krei novan adreson</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopii elektitan adreson al la tondejo</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopii</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Fermi</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Forigi la elektitan adreson el la listo</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Tajpu adreson aŭ etikedon por serĉi</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporti la datumojn el la aktuala langeto al dosiero</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporti</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Forigi</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Elekti la adreson por sendi monerojn</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Elekti la adreson ricevi monerojn kun</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Elekti</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Sendaj adresoj</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Ricevaj adresoj</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Jen viaj Bitmon-adresoj por sendi pagojn. Zorge kontrolu la sumon kaj la alsendan adreson antaŭ ol sendi.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopii Adreson</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopii &amp;Etikedon</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redakti</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksporti Adresliston</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Perkome disigita dosiero (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ekspotado malsukcesinta</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Okazis eraron dum konservo de adreslisto al %1. Bonvolu provi denove.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etikedo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogo pri pasfrazo</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Enigu pasfrazon</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova pasfrazo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ripetu la novan pasfrazon</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Montri pasfrazon</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Ĉifri la monujon</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ĉi tiu operacio bezonas vian monujan pasfrazon, por malŝlosi la monujon.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Malŝlosi la monujon</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ĉi tiu operacio bezonas vian monujan pasfrazon, por malĉifri la monujon.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Malĉifri la monujon</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Ŝanĝi la pasfrazon</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Konfirmo de ĉifrado de la monujo</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Atentu! Se vi ĉifras vian monujon kaj perdas la pasfrazon, vi &lt;b&gt;PERDOS LA TUTON DE VIA BITMONO&lt;b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ĉu vi certas, ke vi volas ĉifri la monujon?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>La monujo estas ĉifrita</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Enigi la novan pasfrazon por la monujo. &lt;br/&gt;Bonvolu uzi pasfrazon de &lt;b&gt;dek aŭ pli hazardaj signoj&lt;/b&gt;, aŭ &lt;b&gt;ok aŭ pli vortoj&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Enigi la malnovan pasfrazon kaj la novan pasfrazon por la monujo.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Monujo ĉifriĝota</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Via monujo estas ĉifriĝota.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Via monujo ĵus estas ĉifrata.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>GRAVE: antaŭaj sekur-kopioj de via monujo-dosiero estas forigindaj kiam vi havas nove kreitan ĉifritan monujo-dosieron. Pro sekureco, antaŭaj kopioj de la neĉifrita dosiero ne plu funkcios tuj kiam vi ekuzos la novan ĉifritan dosieron.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Ĉifrado de la monujo fiaskis</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Ĉifrado de monujo fiaskis pro interna eraro. Via monujo ne estas ĉifrita.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>La pasfrazoj entajpitaj ne samas.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Malŝloso de la monujo fiaskis</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La pasfrazo enigita por ĉifrado de monujo ne ĝustas.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Malĉifrado de la monujo fiaskis</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Vi sukcese ŝanĝis la pasfrazon de la monujo.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Atentu: la majuskla baskulo estas ŝaltita!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation>Ekzilita Ĝis</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Subskribi &amp;mesaĝon...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinkronigante kun reto...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Superrigardo</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Vidigi ĝeneralan superrigardon de la monujo</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcioj</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Esplori historion de transakcioj</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Eliri</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Eliri la aplikaĵon</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Pri %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Montri informojn pri %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Vidigi informojn pri Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Agordoj...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Ŝanĝi agordojn por %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Ĉifri &amp;Monujon...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Krei sekurkopion de la monujo...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Ŝanĝi &amp;Pasfrazon...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Malfermi &amp;URI-on...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>Krei Monujon...</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>Krei novan monujon</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Monujo:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>Retaj agadoj malebliĝas.</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindeksado de blokoj sur disko...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Sendi monon al Bitmon-adreso</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Krei alilokan sekurkopion de monujo</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ŝanĝi la pasfrazon por ĉifri la monujon</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Kontroli mesaĝon...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sendi</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ricevi</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Montri / Kaŝi</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Montri aŭ kaŝi la ĉefan fenestron</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Ĉifri la privatajn ŝlosilojn de via monujo</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Subskribi mesaĝojn per via Bitmon-adresoj por pravigi, ke vi estas la posedanto</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Kontroli mesaĝojn por kontroli ĉu ili estas subskribitaj per specifaj Bitmon-adresoj</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Langeto-breto</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Peti pagon (kreas QR-kodojn kaj URI-ojn kun prefikso bitcoin:)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Vidigi la liston de uzitaj sendaj adresoj kaj etikedoj</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Vidigi la liston de uzitaj ricevaj adresoj kaj etikedoj</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Komandliniaj agordaĵoj</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indeksado de blokoj sur disko...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>mankas %1</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Lasta ricevita bloko kreiĝis antaŭ %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transakcioj por tio ankoraŭ ne videblas.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Averto</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informoj</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ĝisdata</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Malfermi konzolon de sencimigo kaj diagnozo</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Sendaj adresoj</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Ricevaj adresoj</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation>Malfermi na la URI de bitmono</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Malfermi la Monujon</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>Malfermi monujon</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>Fermi la Monujon...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>Fermi monujon</translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>Fermi Ĉiujn Monujojn...</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Fermi ĉiujn monujojn</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestro</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zomi</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>Ĉefa Fenestro</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ĝisdatigante...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Eraro: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Averto: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dato: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Sumo: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>Monujo: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tipo: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Etikedo: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adreso: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Sendita transakcio</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Envenanta transakcio</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Monujo estas &lt;b&gt;ĉifrita&lt;/b&gt; kaj aktuale &lt;b&gt;malŝlosita&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Monujo estas &lt;b&gt;ĉifrita&lt;/b&gt; kaj aktuale &lt;b&gt;ŝlosita&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation>Originala mesaĝo:</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>Neriparebla eraro okazis. %1 ne plu sekure povas daŭri kaj ĝi ĉesiĝos.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Monero-Elektaĵo</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kvanto:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtoj:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Krompago:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Polvo:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Post krompago:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Restmono:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(mal)elekti ĉion</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Arboreĝimo</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Listreĝimo</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Ricevita kun etikedo</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Ricevita kun adreso</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Konfirmoj</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Konfirmita</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopii sumon</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopii adreson</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopii etikedon</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopii sumon</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopii transakcian ID-on</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Ŝlosi la neelspezitajn</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Malŝlosi la neelspezitajn</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopii kvanton</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopii krompagon</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopii post krompago</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopii bajtojn</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopii polvon</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopii restmonon</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 ŝlosita)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>jes</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>restmono de %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(restmono)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation>Krei Monujon</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation>Krei monujon malsukcesis</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation>Averto pro krei monujon</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>Krei Monujon</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Monujo</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>Monujo-Nomo</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Ĉifri Monujon</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation>Malebligi privatajn ŝlosilojn por ĉi tiu monujo. Monujoj kun malebligitaj privataj ŝlosiloj ne havos privatajn ŝlosilojn, kaj povas havi nek HD-semon nek importatajn privatajn ŝlosilojn. Ĉi tio estas ideale por nurspektaj monujoj.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation>Malebligi Privatajn Ŝlosilojn</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Krei</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Redakti Adreson</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etikedo</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>La etikedo ligita al tiu ĉi adreslistero</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>La adreso ligita al tiu ĉi adreslistero. Eblas modifi tion nur por sendaj adresoj.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adreso</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adreso por sendi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Redakti adreson por ricevi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Redakti adreson por sendi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>La adreso enigita "%1" ne estas valida Bitmon-adreso.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ne eblis malŝlosi monujon.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Fiaskis kreo de nova ŝlosilo.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Kreiĝos nova dosierujo por la datumoj.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nomo</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Tiu dosierujo jam ekzistas. Aldonu %1 si vi volas krei novan dosierujon ĉi tie.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Vojo jam ekzistas, kaj ne estas dosierujo.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Ne eblas krei dosierujon por datumoj ĉi tie.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versio</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Pri %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Komandliniaj agordaĵoj</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Bonvenon</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Bonvenon al %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Dum tiu ĉi unua uzo de la programo, vi povas elekti lokon, kie %1 stokos siajn datumojn.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Uzi la defaŭltan dosierujon por datumoj</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Uzi alian dosierujon por datumoj:</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitmono</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Almenaŭ %1GB da datumoj konserviĝos en tiu loko, kaj tio poiome kreskos.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation>%1 elŝutos kaj konservos kopion de la bitmona blokĉeno.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Ankaŭ via monujo konserviĝos en tiu dosierujo.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n gigabajto de libera loko disponeble</numerusform><numerusform>%n gigabajtoj de libera loko disponebla.</numerusform></translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    <message>
        <source>N/A</source>
        <translation>neaplikebla</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Formularo</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Nekonata...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Horo de la lasta bloko</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>Hora pligrandigo da progreso</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>kalkuladas...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Kaŝi</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esk</translation>
    </message>
    <message>
        <source>%1 is currently syncing.  It will download headers and blocks from peers and validate them until reaching the tip of the block chain.</source>
        <translation>%1 sinkronigadas. Ĝi elŝutos kapaĵojn kaj blokojn de samtavolanoj, kaj validigos ilin, ĝis ĝi atingas la pinton de la blokĉeno.</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Adreso</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open bitcoin URI</source>
        <translation>Malfermi na la URI de bitmono</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Alglui adreson de tondejo</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation>Malfermi monujon malsukcesis</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation>Malfermi monujon averto</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>defaŭlta monujo</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>Malfermi la Monujon</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation>Malfermadas Monujon &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Agordaĵoj</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>Ĉ&amp;efa</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>Aŭtomate komenci na %1 post ensalutis en la sistemon.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;Komenci na %1 kiam ensaluti en la sistemon</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Dosiergrando de &amp;datumbasa kaŝmemoro</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Kvanto da skriptaj kaj kontroleraraj fadenoj</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>IP-adreso de prokurilo (ekz. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Reagordi ĉion al defaŭlataj valoroj.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Rekomenci agordadon</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Reto</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Monujo</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Fakulo</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Aŭtomate malfermi la kursilan pordon por Bitmono. Tio funkcias nur se via kursilo havas la UPnP-funkcion, kaj se tiu ĉi estas ŝaltita.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapigi pordon per &amp;UPnP</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Akcepti konektojn el ekstere.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">&amp;Permesi envenantajn konektojn</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Prokurila &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Pordo:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>la pordo de la prokurilo (ekz. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestro</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Montri nur sistempletan piktogramon post minimumigo de la fenestro.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimumigi al la sistempleto anstataŭ al la taskopleto</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimumigi je fermo</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Aspekto</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Lingvo de la fasado:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unuo por vidigi sumojn:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Elekti la defaŭltan manieron por montri bitmonajn sumojn en la interfaco, kaj kiam vi sendos bitmonon.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Ĉu montri detalan adres-regilon, aŭ ne.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Bone</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Nuligi</translation>
    </message>
    <message>
        <source>default</source>
        <translation>defaŭlta</translation>
    </message>
    <message>
        <source>none</source>
        <translation>neniu</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Kerno de Bitmono</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Konfirmi reŝargo de agordoj</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>La prokurila adreso estas malvalida.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formularo</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Eblas, ke la informoj videblaj ĉi tie estas eksdataj. Via monujo aŭtomate sinkoniĝas kun la bitmona reto kiam ili konektiĝas, sed tiu procezo ankoraŭ ne finfariĝis.</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponebla:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>via aktuala elspezebla saldo</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>la sumo de transakcioj ankoraŭ ne konfirmitaj, kiuj ankoraŭ ne elspezeblas</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nematura:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Minita saldo, kiu ankoraŭ ne maturiĝis</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Saldoj</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totalo:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>via aktuala totala saldo</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Elspezebla:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Lastaj transakcioj</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Save...</source>
        <translation>Konservi...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermi</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation>Totala Sumo</translation>
    </message>
    <message>
        <source>or</source>
        <translation>aŭ</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Eraro dum pagopeto</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation>Ne eblas lanĉi la ilon 'klaki-por-pagi'</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Traktado de URI-oj</translation>
    </message>
    <message>
        <source>Invalid payment address</source>
        <translation>Nevalida pagadreso</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Uzanto Agento</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Sendita</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Ricevita</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Neniu</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>neaplikebla</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekundo</numerusform><numerusform>%n sekundoj</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n minuto</numerusform><numerusform>%n minutoj</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n horo</numerusform><numerusform>%n horoj</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n tago</numerusform><numerusform>%n tagoj</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n semajno</numerusform><numerusform>%n semajnoj</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 kaj %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n jaro</numerusform><numerusform>%n jaroj</numerusform></translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" does not exist.</source>
        <translation>Eraro: la elektita dosierujo por datumoj "%1" ne ekzistas.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Eraro: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nekonata</translation>
    </message>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>Tso</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Konservi Bildon...</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Kopii Bildon</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>La rezultanta URI estas tro longa. Provu malplilongigi la tekston de la etikedo / mesaĝo.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Eraro de kodigo de URI en la QR-kodon.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Konservi QR-kodon</translation>
    </message>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>PNG-bildo (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>neaplikebla</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versio de kliento</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informoj</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ĝenerala</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Horo de lanĉo</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Reto</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Nombro de konektoj</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokĉeno</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation>Monujo:</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Ricevita</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Sendita</translation>
    </message>
    <message>
        <source>&amp;Peers</source>
        <translation>&amp;Samuloj</translation>
    </message>
    <message>
        <source>Banned peers</source>
        <translation>Malpermesita samuloj.</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Uzanto Agento</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Servoj</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Horo de la lasta bloko</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Malfermi</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzolo</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Reta Trafiko</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>En:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>El:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Sencimiga protokoldosiero</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Malplenigi konzolon</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1 &amp;horo</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1 &amp;semajno</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1 &amp;jaro</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Al</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>1 d&amp;ay</source>
        <translation type="unfinished">1 &amp;tago</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Kopii adreson</translation>
    </message>
    <message>
        <source>&amp;Unban</source>
        <translation>&amp;Malekzili</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation type="unfinished">Retaj agadoj malebliĝas</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nekonata</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Kvanto:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etikedo:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Mesaĝo:</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Peti pagon</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Malplenigi ĉiujn kampojn de la formularo.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Vidigi</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopii &amp;URI</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopii adreson</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopii etikedon</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;Kopiu mesaĝon</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopii sumon</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ne eblis malŝlosi monujon.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Request payment to ...</source>
        <translation type="unfinished">Peti pagon al ...</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adreso:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumo:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Etikedo:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mesaĝo:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Monujo:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopii &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Kopii &amp;Adreson</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Konservi Bildon...</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation>Peti pagon al %1</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Paginformoj</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikedo</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mesaĝo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(neniu mesaĝo)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Sendi Bitmonon</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Monregaj Opcioj</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Enigoj...</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nesufiĉa mono!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kvanto:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtoj:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Krompago:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Post krompago:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Restmono:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Krompago:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Elekti...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Kaŝi</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Sendi samtempe al pluraj ricevantoj</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Aldoni &amp;Ricevonton</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Malplenigi ĉiujn kampojn de la formularo.</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Polvo:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Forigi Ĉion</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Konfirmi la sendon</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Ŝendi</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopii kvanton</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopii sumon</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopii krompagon</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopii post krompago</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopii bajtojn</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopii polvon</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopii restmonon</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 al %2</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Ĉu vi certas, ke vi volas sendi?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>aŭ</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Krompago</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation>Totala Sumo</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Konfirmi sendon de bitmono</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Sendi</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>La pagenda sumo devas esti pli ol 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>La sumo estas pli granda ol via saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>La sumo kun la %1 krompago estas pli granda ol via saldo.</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>Kreo de transakcio fiaskis!</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>Averto: Nevalida Bitmon-adreso</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Sumo:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Ricevonto:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etikedo:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Elektu la jam uzitan adreson</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Alglui adreson de tondejo</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Forigu ĉi tiun enskribon</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mesaĝo:</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to the list of used addresses</source>
        <translation>Tajpu etikedon por tiu ĉi adreso por aldoni ĝin al la listo de uzitaj adresoj</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Pagi Al:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memorando:</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Ne sistemfermu ĝis ĉi tiu fenestro malaperas.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Subskriboj - Subskribi / Kontroli mesaĝon</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Subskribi Mesaĝon</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Elektu la jam uzitan adreson</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Alglui adreson de tondejo</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Tajpu la mesaĝon, kiun vi volas sendi, cîi tie</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Subskribo</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopii la aktualan subskribon al la tondejo</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation>Subskribi la mesaĝon por pravigi, ke vi estas la posedanto de tiu Bitmon-adreso</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Subskribi &amp;Mesaĝon</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Reagordigi ĉiujn prisubskribajn kampojn</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Forigi Ĉion</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Kontroli Mesaĝon</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation>Kontroli la mesaĝon por pravigi, ke ĝi ja estas subskribita per la specifa Bitmon-adreso</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Kontroli &amp;Mesaĝon</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Reagordigi ĉiujn prikontrolajn kampojn</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klaku "Subskribi Mesaĝon" por krei subskribon</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>La adreso, kiun vi enmetis, estas nevalida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Bonvolu kontroli la adreson kaj reprovi.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>La adreso, kiun vi enmetis, referencas neniun ŝlosilon.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Malŝloso de monujo estas nuligita.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La privata ŝlosilo por la enigita adreso ne disponeblas.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Subskribo de mesaĝo fiaskis.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mesaĝo estas subskribita.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Ne eblis malĉifri la subskribon.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Bonvolu kontroli la subskribon kaj reprovu.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La subskribo ne kongruis kun la mesaĝ-kompilaĵo.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Kontrolo de mesaĝo malsukcesis.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mesaĝo sukcese kontrolita.</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Malferma ĝis %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nekonfirmite</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmoj</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonto</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Kreita</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nekonata</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Al</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>propra adreso</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etikedo</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kredito</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>ne akceptita</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debeto</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Krompago</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neta sumo</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mesaĝo</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komento</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>Transakcia ID</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>Vendisto</translation>
    </message>
    <message>
        <source>Generated coins must mature %1 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>Kreitaj moneroj devas esti maturaj je %1 blokoj antaŭ ol eblas elspezi ilin. Kiam vi generis tiun ĉi blokon, ĝi estis elsendita al la reto por aldono al la blokĉeno. Se tiu aldono malsukcesas, ĝia stato ŝanĝiĝos al "neakceptita" kaj ne eblos elspezi ĝin. Tio estas malofta, sed povas okazi se alia bloko estas kreita je preskaŭ la sama momento kiel la via.</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Sencimigaj informoj</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakcio</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation>Enigoj</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message>
        <source>true</source>
        <translation>vera</translation>
    </message>
    <message>
        <source>false</source>
        <translation>malvera</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Tiu ĉi panelo montras detalan priskribon de la transakcio</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikedo</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Malferma ĝis %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Nekonfirmita</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Konfirmita (%1 konfirmoj)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Kreita sed ne akceptita</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ricevita kun</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ricevita de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendita al</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pago al vi mem</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minita</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>neaplikebla</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transakcia stato. Ŝvebi super tiu ĉi kampo por montri la nombron de konfirmoj.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Dato kaj horo kiam la transakcio alvenis.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo de transakcio.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Sumo elprenita de aŭ aldonita al la saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Ĉiuj</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hodiaŭ</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Ĉi-semajne</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ĉi-monate</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Pasintmonate</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ĉi-jare</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervalo...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ricevita kun</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendita al</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minita</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Aliaj</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimuma sumo</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopii adreson</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopii etikedon</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopii sumon</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopii transakcian ID-on</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Redakti etikedon</translation>
    </message>
    <message>
        <source>&amp;Show transaction details</source>
        <translation type="unfinished">&amp;Montri detalojn de transakcio</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Perkome disigita dosiero (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Konfirmita</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikedo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ekspotado malsukcesinta</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervalo:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>al</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>Fermi monujon</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>Fermi ĉiujn monujojn</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>Krei novan monujon</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Sendi Bitmonon</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>defaŭlta monujo</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporti</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporti la datumojn el la aktuala langeto al dosiero</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Krei sekurkopion de monujo</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Monuj-datumoj (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Malsukcesis sekurkopio</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>Sukcesis krei sekurkopion</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Nuligi</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation>Tiu ĉi estas antaŭeldona testa versio - uzu laŭ via propra risko - ne uzu por minado aŭ por aplikaĵoj por vendistoj</translation>
    </message>
    <message>
        <source>Warning: The network does not appear to fully agree! Some miners appear to be experiencing issues.</source>
        <translation>Averto: La reto ne tute konsentas! Kelkaj minantoj ŝajne spertas problemojn aktuale.</translation>
    </message>
    <message>
        <source>Warning: We do not appear to fully agree with our peers! You may need to upgrade, or other nodes may need to upgrade.</source>
        <translation>Averto: ŝajne ni ne tute konsentas kun niaj samtavolanoj! Eble vi devas ĝisdatigi vian klienton, aŭ eble aliaj nodoj faru same.</translation>
    </message>
    <message>
        <source>Cannot resolve -%s address: '%s'</source>
        <translation>Ne eblas trovi la adreson -%s: '%s'</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation>Difektita blokdatumbazo trovita</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Ĉu vi volas rekonstrui la blokdatumbazon nun?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Eraro dum pravalorizado de blokdatumbazo</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>Eraro dum pravalorizado de monuj-datumbaza ĉirkaŭaĵo %s!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Eraro dum ŝargado de blokdatumbazo</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Eraro dum malfermado de blokdatumbazo</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ne sukcesis aŭskulti ajnan pordon. Uzu -listen=0 se tion vi volas.</translation>
    </message>
    <message>
        <source>Incorrect or no genesis block found. Wrong datadir for network?</source>
        <translation>Geneza bloko aŭ netrovita aŭ neĝusta. Ĉu eble la datadir de la reto malĝustas?</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>Ŝarĝante adresojn...</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation>Nesufiĉa nombro de dosierpriskribiloj disponeblas.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Kontrolado de blokoj...</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Subskriba transakcio fiaskis</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>ĝi estas eksperimenta programo</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Transakcia sumo tro malgranda</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transakcio estas tro granda</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>Kontrolado de monujo...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Nekonata reto specifita en -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nesufiĉa mono</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ŝarĝante blok-indekson...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ŝargado de monujo...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Reskanado...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ŝargado finiĝis</translation>
    </message>
</context>
</TS>